#
# spec file for package exiv2
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           exiv2-0_26
Version:        0.26
Release:        150400.9.16.1
Summary:        Tool to access image Exif metadata
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Other
URL:            http://www.exiv2.org/
Source0:        https://github.com/Exiv2/exiv2/archive/v0.26.tar.gz
Source1:        baselibs.conf
Patch1:         exiv2-build-date.patch
Patch2:         parallel-build-dep.patch
# git diff --no-merges v0.26..upstream/0.26
Patch3:         exiv2-update-to-0.26-branch.patch
Patch4:         0001-Avoid-null-pointer-exception-due-to-NULL-return-valu.patch
Patch5:         0001-IptcData-printStructure-Remove-buffer-overrun.patch
Patch6:         0001-Fix-SEGV-in-DataValue-Copy.patch
Patch7:         0001-PSD-Use-Safe-add-for-preventing-overflows-in-PSD-fil.patch
Patch8:         0002-PSD-enforce-Length-of-image-resource-section-file-si.patch
Patch9:         0001-Fix-561.-Use-proper-counter-for-the-idx-variable.patch
Patch14:        CVE-2018-5772.patch
Patch15:        CVE-2018-8976.patch
Patch16:        CVE-2018-8977.patch
Patch17:        CVE-2020-18898.patch
Patch18:        CVE-2021-31291.patch
Patch19:        CVE-2021-31292.patch
Patch20:        CVE-2021-37618.patch
Patch21:        CVE-2021-37619.patch
Patch22:        CVE-2020-18899.patch
Patch23:        CVE-2018-10772.patch
Patch24:        CVE-2018-18915.patch
Patch25:        CVE-2021-37620.patch
Patch26:        CVE-2021-29470.patch
Patch27:        CVE-2021-37621.patch
Patch28:        CVE-2021-32617.patch
Patch29:        CVE-2020-19716.patch
Patch30:        CVE-2019-14368.patch
Patch31:        CVE-2019-20421.patch
Patch32:        CVE-2019-13111.patch
Patch33:        webp-alpha-detection.patch
Patch34:        CVE-2021-29463.patch
Patch35:        improve-pngchunk-bounds-checking.patch
Patch36:        CVE-2021-34334.patch
BuildRequires:  autoconf
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
# doxygen likes to have this
BuildRequires:  graphviz
BuildRequires:  libexpat-devel
BuildRequires:  libxslt
BuildRequires:  pkgconfig
BuildRequires:  python3-base
BuildRequires:  zlib-devel
Recommends:     %{name}-lang = %{version}

%description
Exiv2 is a command line utility to access image metadata from tags like
Exif.

%package -n libexiv2-26
Summary:        Library to access image metadata
Group:          System/Libraries

%description -n libexiv2-26
libexiv2 is a C++ library with a C compatibility interface to access
image metadata, esp from Exif tags.

%package -n libexiv2-devel
Summary:        Development Headers for Exiv2
Group:          Development/Libraries/C and C++
Requires:       libexiv2-26 = %{version}
Requires:       libstdc++-devel

%description -n libexiv2-devel
Exiv2 is a C++ library and a command line utility to access image
metadata.

%package -n libexiv2-doc
Summary:        Library to access image metadata - Documentation
Group:          System/Libraries

%description -n libexiv2-doc
libexiv2 is a C++ library with a C compatibility interface to access
image metadata, esp from Exif tags. This package contains the developer
documentation in HTML format.

%lang_package

%prep
%autosetup -p1 -n exiv2-%version

# use python3 not env python
sed -i -e 's:#! %{_bindir}/env python:#!%{_bindir}/python3:' doc/templates/gen.py

%build

export CXXFLAGS="%{optflags} $(getconf LFS_CFLAGS)"
%cmake \
  -DEXIV2_ENABLE_BUILD_PO:BOOL=ON \
  -DEXIV2_ENABLE_BUILD_SAMPLES:BOOL=OFF
make %{?_smp_mflags}
make %{?_smp_mflags} doc

%install
%cmake_install
%find_lang exiv2
%fdupes -s doc/html
find %{buildroot} -type f -name "*.la" -delete -print
rm -f %{buildroot}%{_libdir}/*.a
rm %{buildroot}%{_libdir}/pkgconfig/exiv2.lsm

# only package the library
cat - <<EOF  | while read n; do rm -rv "$n"; done
%{buildroot}%{_bindir}/exiv2
%{buildroot}%{_includedir}/exiv2
%{buildroot}%{_mandir}/man1/exiv2.1
%{buildroot}%{_datadir}/locale
%{buildroot}%{_libdir}/libexiv2.so
%{buildroot}%{_libdir}/pkgconfig/exiv2.pc
EOF


%post -n libexiv2-26 -p /sbin/ldconfig
%postun -n libexiv2-26 -p /sbin/ldconfig

%files -n libexiv2-26
%{_libdir}/libexiv2.so.*

%changelog
* Fri Oct 28 2022 dmueller@suse.com
- add CVE-2021-34334.patch (CVE-2021-34334, bsc#1189338)
* Wed Oct 26 2022 dmueller@suse.com
- add CVE-2019-13111.patch (CVE-2019-13111, bsc#1142679)
- add CVE-2021-29463.patch (CVE-2021-29463, bsc#1185913)
- add webp-alpha-detection.patch
- add improve-pngchunk-bounds-checking.patch
* Wed Sep 28 2022 dmueller@suse.com
- add exiv2 0.26 library for compatibility (jsc#PED-1393)
* Tue Sep 27 2022 dmueller@suse.com
- add CVE-2021-37621.patch (CVE-2021-37621, bsc#1189333)
- add CVE-2021-32617.patch (CVE-2021-32617, bsc#1186192)
- add CVE-2020-19716.patch (CVE-2020-19716, bsc#1188645)
- add CVE-2019-14368.patch (CVE-2019-14368, bsc#1143278)
- add CVE-2019-20421.patch (CVE-2019-20421, bsc#1161901)
* Mon Sep 26 2022 dmueller@suse.com
- add CVE-2018-10772.patch (CVE-2018-10772, bsc#1092096)
- add CVE-2018-18915.patch (CVE-2018-18915, bsc#1114690)
- add CVE-2021-37620.patch (CVE-2021-37620, bsc#1189332)
- add CVE-2021-29470.patch (CVE-2021-29470, bsc#1185447)
* Fri Aug 12 2022 dmueller@suse.com
- add CVE-2018-5772.patch (CVE-2018-5772, bsc#1076579)
- add CVE-2018-8976.patch (CVE-2018-8976, bsc#1086810)
- add CVE-2018-8977.patch (CVE-2018-8977, bsc#1086798)
- add CVE-2020-18898.patch (CVE-2020-18898, bsc#1189780)
- add CVE-2021-31291.patch (CVE-2021-29457 and CVE-2021-31291, bsc#1185002 and bsc#1188733)
- add CVE-2021-31292.patch (CVE-2021-31292, bsc#1188756)
- add CVE-2021-37618.patch (CVE-2021-37618, bsc#1189330)
- add CVE-2021-37619.patch (CVE-2021-37619, bsc#1189331)
- add CVE-2020-18899.patch (CVE-2020-18899, bsc#1189636)
* Tue Mar 24 2020 dmueller@suse.com
- add 0001-Avoid-null-pointer-exception-due-to-NULL-return-valu.patch (bsc#1142684, CVE-2019-13114):
  * fixes null-pointer dereference in http.c causing denial of service
- add 0001-IptcData-printStructure-Remove-buffer-overrun.patch  (bsc#1088424, CVE-2018-9305):
  * fixes an out-of-bounds read in IptcData::printStructure in iptc.c
- add 0001-Fix-SEGV-in-DataValue-Copy.patch (bsc#1109299, CVE-2018-17282):
  * fixes null pointer dereference in Exiv2:DataValue:copy in value.cpp
- add 0001-PSD-Use-Safe-add-for-preventing-overflows-in-PSD-fil.patch,
  0002-PSD-enforce-Length-of-image-resource-section-file-si.patch (CVE-2018-19108, bsc#1115364):
  * fixes denial of service in Exiv2::PsdImage::readMetadata
- add 0001-Fix-561.-Use-proper-counter-for-the-idx-variable.patch (CVE-2018-19607, bsc#1117513):
  * fixes a denial of service (NULL pointer dereference and application crash)
* Tue Oct 16 2018 dmueller@suse.com
- update to latest 0.26 branch:
  * Includes fix for CVE-2019-14982 (bsc#1146294)
  * Fixes CVE-2018-12264, CVE-2018-12265 (bsc#1097599)
  * Fixes CVE-2017-9239 (bsc#1040973): null pointer dereference in doWriteImage
  * Fixes CVE-2018-17229 (bsc#1109175): (Heap buffer overflow in Exiv2::d2Data)
  * Fixes CVE-2018-17230 (bsc#1109176): (heap-based buffer overflow in Exiv2::ul2Data)
  * Fixes CVE-2017-1000126 (Stack out of bounds read in webp parser) (bsc#1068873)
* Fri Jun 29 2018 tchvatal@suse.com
- Fix build on python3 only system by making sure we use
  python3 when building
* Wed May 30 2018 dmueller@suse.com
- update to latest 0.26 branch:
  * obsoletes 0001-Use-more-GNUInstallDirs.patch
  d4e4288d839d0d9546a05986771f8738c382060c.patch
  gcc-version-check.patch
  7f5b0778fa301b68c1c88e3820ec3afbd09dd0a5.patch
  fix-crash.patch
  * adds exiv2-update-to-0.26-branch.patch
  * Fixes CVE-2017-14864 (bsc#1060995),
  CVE-2017-14862 (bsc#1060996), CVE-2017-14859 (bsc#1061000)
  CVE-2017-14860 (bsc#1048883), CVE-2017-11337 (bsc#1048883),
  CVE-2017-11338 (bsc#1048883), CVE-2017-11339 (bsc#1048883),
  CVE-2017-11340 (bsc#1048883), CVE-2017-11553,
  CVE-2017-12955 (bsc#1054593), CVE-2017-12956,
  CVE-2017-12957, CVE-2017-11683, CVE-2017-11592,
  CVE-2017-11591 (bsc#1050257)
* Fri Nov 24 2017 cfeck@kde.org
- split developer documentation into separate package
* Tue Oct 17 2017 dmueller@suse.com
- add 0001-Use-more-GNUInstallDirs.patch (bsc#938600)
- add d4e4288d839d0d9546a05986771f8738c382060c.patch (
    CVE-2017-14864 bsc#1060995,
    CVE-2017-14862 bsc#1060996,
    CVE-2017-14859 bsc#1061000)
* Wed Aug  9 2017 wbauer@tmo.at
- Add fix-crash.patch to prevent crashes in gwenview with certain
  images (boo#1051782)
- Update source tarball to the fixed upstream re-release and remove
  the workaround in the spec file
- Replace gcc-version-check.patch with the version committed
  upstream
* Tue Jul  4 2017 wbauer@tmo.at
- Fix baselibs.conf
* Fri Jun 30 2017 wbauer@tmo.at
- Update to version 0.26
  * See http://www.exiv2.org/changelog.html
- Add gcc-version-check.patch to fix build on Tumbleweed
- Dropped the following upstreamed patches:
  * exiv2-cmake-libsuffix.patch
  * exiv2_r3889_r3890_fix_boo964344.diff
* Thu May  5 2016 suse-beta@cboltz.de
- add exiv2_r3889_r3890_fix_boo964344.diff (taken from revisions linked
  in http://dev.exiv2.org/issues/1106) to fix crash in darktable (boo#964344)
* Wed Jul 15 2015 jengelh@inai.de
- Adjust RPM groups
- Put manpage in proper subpackage
* Tue Jun 23 2015 dmueller@suse.com
- readd parallel-build-dep.patch
* Mon Jun 22 2015 tittiatcoke@gmail.com
- Update to version 0.25
  * exivsimple has array index errors when stripping quotes form
    trivial input strings
  * Use SVN eol-style LF on all files
  * Access violation on IptcData::operator[] when key is invalid
  * PNG images with tiff tags throw exceptions
  * Plasma kde crashes when specific jpeg is on the Desktop
  * TIFF parser,Binary array elements should be decoded using the
    Makernote's endianness, not that of the image
  * Coverity scan : Issue CID 981992 , 981993
  * Wrong key name in output of addmodel sample
  * Printing tags does not honor multi-byte label widths correctly
  * Wrong ApertureValue written
  * pyexiv2 fails on cifs shares on an Ubuntu client
  * TIFF parser,Parse TIFF PageNumber
  * Add new sample applications exifdata and exivvalue
  * Add option -K Key (--key Key) to specify one or more keys to
    output
  * "exiv2 -eX" followed by "exiv2 -iX" produces invalid XMP
    metadata packet
  * Sony NEX Lens Information
  * Handle Pentax makernotes in samsung-rebranded cameras
  * Olympus XZ-1 FocusDistance incorrect
  * Support Panasonic Makernote
  * detection of Pentax DA 35/2.4 lens
  * Canon EOS M EF-M lenses
  * Lens matching on Canon
  * Tamron 18-270 is not detected anymore
  * Wrong aperture for Tamron 70-300?
  * Recognize Samsung NX 10mm Fisheye
  * Pentax/Sigma 24-70mm F2.8 IF EX DG HSM data
  * See also http://www.exiv2.org/changelog.html
- Dropped the following upstreamed patches:
  * fix-overflow-in-info-tags-r3264.patch
  * fix-video-timescale-handling.patch
  * parallel-build-dep.patch
  * fix-parallel-build.patch
* Thu Jun 18 2015 dimstar@opensuse.org
- Switch to cmake build system: there are various code snips that
  use variables that are only defined in the cmake build system
  (e.g. src/utils.cpp uses EXV_HAVE_UNISTD_H to include unistd.h,
  which is not done with configure. With gcc5 this results now in
  a failure, as unistd.h is no longer implicit).
- Add exiv2-cmake-libsuffix.patch: Install the library to lib64 on
  the respective archs.
* Sun May 24 2015 gernot@hillier.de
- add fix-video-timescale-handling.patch: Fix crash when scanning mp4 videos.
* Tue May 12 2015 dmueller@suse.com
- add parallel-build-dep.patch: Fix build dependencies
* Mon Feb  9 2015 nico.kruber@gmail.com
- fix a Buffer Overflow in INFO tags of RIFFVIDEO.CPP
  (fix-overflow-in-info-tags-r3264.patch) (CVE-2014-9449).
* Mon May 26 2014 crrodriguez@opensuse.org
- Build with large file support in 32 bit systems.
- Ensure we do not use __DATE__ or __TIME__ anywhere
  (exiv2-build-date.patch)
* Mon May  5 2014 coolo@suse.com
- add fix-parallel-build.patch to fix -j, notified upstream about it
* Mon Apr 14 2014 ctrippe@opensuse.org
- Update to version 0.24
  * exiv2 (0.19-1) 00_hyphens_used_as_minus.diff
  * (Reported with patch by Mark Purcell, fixed by Niels Kristian Bech Jensen)
  * Video metadata support (Abhinav Badola for GSoC 2012)
  * Samsung NX100 JPG exports have broken EXIF (Reported by Pascal de Bruijn)
  * Warnings while compiling with g++4.5
  * (Reported by Sebastien Gilles, fixed by Robin Mills)
  * For TIFF-like images, non-intrusive writing is not used when it should
  * (Reported by Thomas Lotze)
  * Patch to detect Carl Zeiss Planar T* 50mm f/1.4 ZE on Canon
  * (Reported with patch by Stian Grindvoll)
  * Exiv2 fails to compile under Linux (Volker Grabsch)
  * example1.cpp clang Mac OS X warnings (Reported by Jerry Jacobs)
  * Exiv2 crashes on input (Reported by Christian Grothoff)
  * Complete Samsung NX lenses portfolio recognition
  * (Reported with patch by Jaroslav Stepanek, updates by Pascal de Bruijn)
  * Porting the Video Code to MSVC (umbrella)
  * (Robin Mills, Abhinav Badola, Shawn Xiong)
  * Photoshop doesn't recognize its own EPS files after modification by Exiv2
  * (Volker Grabsch)
  * autotools build (make config ; ./configure ; make) is broken
  * (Robin Mills)
  * Sigma 50mm f/1.4 on Canon not detected correctly
  * (Reported by Rick Gabriel, patch by Aakash Goenka)
  * PENTAX-DA 18-135mm F3.5-5.6 not detected correctly
  * (Reported by S. Verdoold, patch by Pascal de Bruijn)
  * Sigma 18-250mm not properly recognised on Pentax
  * (Reported by S. Verdoold, patch by Pascal de Bruijn)
  * Video code is failing the test suite (on all plaforms)
  * (Robin Mills, Abhinav Badola)
  * Patches for locale and boost issue (Patches by Mario anyc)
  * Support for two lens for sony mount
  * (Patch by Michal Babej)
  * Exif.OlympusEq.0x0403 tag
  * (Christoph Anton Mitterer, Robin Mills)
  * New Samsung NX 12-24mm f/4-5.6 ED
  * (Jaroslav Stepanek)
  * New lens "Tamron SP 24-70mm F/2.8 Di VC USD"
  * (Reported by Jean-Pierre Verrue, patch by Niels Kristian Bech Jensen)
  * New lens: Canon EF 35mm f/2 IS USM
  * (markus kanet, Robin Mills)
  * New camera: Canon EOS 6D
  * (markus kanet)
  * Update list of lenses for Olympus cameras.
  * (Niels Kristian Bech Jensen)
  * Add another lens for Olympus cameras.
  * (Niels Kristian Bech Jensen)
  * Another bunch of Olympus lens updates.
  * (Niels Kristian Bech Jensen)
  * One more Olympus lens - the list is complete.
  * (Niels Kristian Bech Jensen)
  * Nikon AF-S Nikkor 28mm f/1.8G not recognized
  * (Reported by Philip Johnsson, patch by Niels Kristian Bech Jensen)
  * Missing lenses reported by Paul Bissonnette
  * (Robin Mills)
  * Samsung D-Xenon 12-24mm not recognized
  * (Reported by Romain Henriet, patch by S. Verdoold)
  * (near-)infinite loop in video decoders
  * (Reported by Alyssa Milburn, patch by Abhinav Badola)
  * ASF: heap overflow
  * (Reported by Alyssa Milburn, patch by Abhinav Badola)
  * Sigma 30mm f/1.4 on Canon not detected correctly
  * (Reported by Christian Roumano, patch by Aakash Goenka)
  * User-readable output of Olympus' FocusDistance
  * (Patch by Teemu Rytilahti)
  * New Compilation Warnings
  * New lens: Pentax smc DA 18-135mm f/3.5-5.6 ED AL [IF] DC WR
  * (Reported by Matthieu Volat, patch by Pascal de Bruijn)
  * New Lens: Canon EF-S 55-250mm f/4-5.6 IS II
  * (Patch by Andrew Aylett)
  * Exiv2: lensName misreporting for some CR2s
  * (Reported by Pascal de Bruijn, patch by Niels Kristian Bech Jensen)
  * Mountain Lion Plugin crashes when setxattr called
  * (Robin Mills)
  * New Lens: Samsung NX 45mm f1.8
  * (Pascal de Bruijn)
  * strerror_r gives no error message back
  * (Reported by Ákos Szőts, patch by Robin Mills)
  * New Lens: Samsung NX 45mm f1.8 2D/3D
  * (Pascal de Bruijn)
  * New Lens: Sigma 150-500mm f/5-6.3 APO DG OS HSM on Canon (Steve Fosdick)
  * Maintenance of Sony Makernote (Patch by Thomas Beutlich)
- Removed patches included in the new release
  * 90_changeset_r2743.diff
  * 90_changeset_r2744.diff
  * 90_changeset_r2756.diff
  * 90_changeset_r2818_partial.dif
  * 90_changeset_r2860.diff
  * 90_changeset_r2889.diff
  * 90_changeset_r2958.diff
  * 90_changeset_r2959.diff
  * 90_changeset_r2961.diff
  * 90_changeset_r2963.diff
  * 90_changeset_r2968.diff
  * 90_changeset_r2969.diff
  * 90_changeset_r2970.diff
  * 90_changeset_r2975.diff
  * 90_changeset_r2978.diff
  * 90_changeset_r2981.diff
  * 90_changeset_r2982.diff
  * 90_changeset_r2984.diff
  * 90_changeset_r2985.diff
  * 90_changeset_r2986.diff
  * 90_changeset_r2988.diff
  * 90_changeset_r2989.diff
  * 90_changeset_r2990.diff
  * 90_changeset_r2991.diff
  * 90_changeset_r2992.diff
  * 90_changeset_r2993.diff
  * 90_changeset_r2994.diff
  * 90_changeset_r2995.diff
  * 90_changeset_r2998.diff
  * 90_changeset_r3002.diff
  * 90_changeset_r3003.diff
  * 90_changeset_r3004.diff
  * 90_changeset_r3005.diff
  * 90_changeset_r3006.diff
  * 90_changeset_r3011.diff
  * 90_changeset_r3016.diff
  * 90_changeset_r3017.diff
  * 90_changeset_r3023.diff
  * 90_changeset_r3026.diff
  * 90_changeset_r3036.diff
  * 90_changeset_r3037.diff
  * 90_changeset_r3038.diff
  * 90_changeset_r3039.diff
  * 90_changeset_r3047.diff
  * 90_changeset_r3048.diff
  * 90_changeset_r3051.diff
  * 90_changeset_r3052.diff
  * 90_changeset_r3053.diff
  * 90_changeset_r3054.diff
  * 90_changeset_r3055.diff
  * 90_changeset_r3060.diff
  * 90_changeset_r3061.diff
  * 90_changeset_r3062.diff
  * 90_changeset_r3063.diff
  * 90_changeset_r3066.diff
  * 90_changeset_r3067.diff
  * 90_changeset_r3068.diff
  * 95_post_r3026_cleanup.diff
- Rename libexiv2-12 subpackage to libexiv2-13 following upstream
  soversion change.
* Fri Jul 26 2013 mrueckert@suse.de
- Backport patches from upstream (cherry-picking courtesy of Pascal
  de Bruijn):
  * 90_changeset_r3036.diff: Canon EF-S 55-250mm f/4-5.6 IS II
  * 90_changeset_r3037.diff: A few more Pentax lenses
  * 90_changeset_r3038.diff: Updates for the Minolta Bodies
  * 90_changeset_r3039.diff: Added 18-55mm f/3.5-5.6 IS STM
  * 90_changeset_r3047.diff: Added Sigma 60mm to the Olympus list
  * 90_changeset_r3048.diff: Added Sigma 19 and 30m to the Olympus
    list
  * 90_changeset_r3051.diff: Added a lot more canon compacts
  * 90_changeset_r3052.diff: Sigma 17-50mm F2.8 EX DC HSM
  * 90_changeset_r3053.diff: Removed Optio M30 from the Pentax list
  * 90_changeset_r3054.diff: Added Samsung NX 45mm F1.8
  * 90_changeset_r3055.diff: Added Samsung NX 45mm F1.8 2D/3D
  * 90_changeset_r3060.diff: Renamed LensModel to LensType in the
    Olympus struct.
  * 90_changeset_r3061.diff: Fixes Issue# 908
  * 90_changeset_r3062.diff: More entries for Pentax
  * 90_changeset_r3063.diff: Do not try to guess lenses when it is
    undefined
  * 90_changeset_r3066.diff: Lumix G Vario 14-140mm F3.5-5.6 Asph.
    Power OIS
  * 90_changeset_r3067.diff: Lumix G Vario 14-42mm F3.5-5.6 II
    Asph. Mega OIS
  * 90_changeset_r3068.diff: Added EOS 70D
* Mon Jun  3 2013 fcrozat@suse.com
- Remove pending patches with upstream versions :
  + 99_pending_canon_eos_m.diff (replaced by
    90_changeset_r2993.diff).
  + 99_pending_minolta_manual_lens.diff (replaced by
    90_changeset_r2989.diff).
  + 99_pending_pentax_da_35.diff (replaced by
    90_changeset_r2860.diff).
  + 99_pending_zeiss_planar_35_ze.diff (replaced by
    90_changeset_r3011.diff).
- Backport patches from upstream (cherry-picking courtesy of Pascal
  de Bruijn):
  + 90_changeset_r2889.diff, 90_changeset_r2985.diff: additional
    lenses for Pentax body.
  + 90_changeset_r2958.diff: additional lenses for Samsung body
  + 90_changeset_r2959.diff, 90_changeset_r2961.diff,
    90_changeset_r2985.diff, 90_changeset_r3003.diff,
    90_changeset_r3016.diff, 90_changeset_r3017.diff: additional
    lenses for Pentax body.
  + 90_changeset_r2963.diff, 90_changeset_r2994.diff,
    90_changeset_r3004.diff, 90_changeset_r3023.diff,
    90_changeset_r3026.diff: additional lenses for Canon body.
  + 90_changeset_r2968.diff, 90_changeset_r2969.diff,
    90_changeset_r2995.diff, 90_changeset_r3005.diff,
    90_changeset_r3006.diff: additional lenses for Minolta body.
  + 90_changeset_r2970.diff, 90_changeset_r2975.diff,
    90_changeset_r2978.diff, 90_changeset_r2981.diff,
    90_changeset_r2982.diff, 90_changeset_r2992.diff: additional
    lenses for Olympus body.
  + 90_changeset_r2998.diff: add support for FocusDistance data
    from Olympus EXIF tags.
  + 90_changeset_r2984.diff, 90_changeset_r2986.diff,
    90_changeset_r3002.diff: additional lenses for Nikon body.
  + 90_changeset_r2988.diff: add support for Exif.Photo.LensModel
    EXIF tag.
  + 90_changeset_r2990.diff: prevent double variable creation.
  + 90_changeset_r2991.diff: fix memory corruption.
  + 95_post_r3026_cleanup.diff: cleanup lenses names.
* Wed Sep 19 2012 fcrozat@suse.com
- Add 90_changeset_r2743.diff: add support for additional Samgsung
  EXIF tags (backport for upstream)
- Add 90_changeset_r2744.diff: add support for additional Pentax
  EXIF tags (backport for upstream)
- Add more Canon models (5D Mark III, 600D, 60D, 1100D, WFT-E2 II,
  WFT-E4 II, 650D)
- Add 90_changeset_r2756.diff: add support for EOS-M Sigma 12-24mm
  f/4.5-5.6 DG HSM II lens (backport from upstream)
- Add 90_changeset_r2818_partial.diff: add support for additional
  Canon camera (5D Mark III, 600D, 60D, 1100D, WFT-E2 II, WFT-E4
  II, 650D) and EF/EF-M lenses. (backport from upstream)
- Add 99_pending_canon_eos_m.diff: add support for some Canon EOS-M
  lenses (pending upstream merge)
- Add 99_pending_minolta_manual_lens.diff: add support for Minolta
  manual lens (pending upstream merge)
- Add 99_pending_pentax_da_35.diff: add support for PENTAX-DA 35mm
  F2.4 AL lens (pending upstream merge)
- Add 99_pending_zeiss_planar_35_ze.diff: add support for Carl
  Zeiss Planar T* 50mm f/1.4 ZE lens (pending upstream merge)
* Wed Apr 25 2012 vuntz@opensuse.org
- Update to version 0.23:
  + Add write support for Canon CR2 raw images.
  + Add support for CR2 IFD2 image preview.
  + Add support for Pentax makernotes in Pentax native DNG images.
  + Add several KIPI XMP properties.
  + Add support for Windows Live Photo Gallery face tags.
  + Add MS Photo RegionInfo and MetaWorkingGroup Regions schemas.
  + Update various lens lists
  + Exiv2 utility: Allow to add/set tags without a value with the
    command line tool.
  + Several new minor features.
  + Bugfixes.
- Rename libexiv2-11 subpackage to libexiv2-12 following upstream
  soversion change.
* Sun Sep 18 2011 jengelh@medozas.de
- Add BuildRequires: graphviz to resolve "sh: dot: command not
  found" and make doxygen happy
* Sun Sep 18 2011 coolo@suse.com
- ran spec-cleaner
* Sun Sep 18 2011 coolo@suse.com
- update to 0.22
  This release introduces support for Postscript (EPS) images.
  XMP metadata can be read and written from/to EPS images and
  previews are accessible.
  Further it includes a new build environment for MSVC 64 bit
  builds and a number of smaller features and bugfixes.
* Fri May 20 2011 dmueller@suse.de
- update to 0.21.1:
  Cannot extract exif data from Pentax K-x DNG file.
  Crash when writing Exif.Image.Software.
  Assertion in XmpParser::encode should be an exception.
  Regression: Compilation error with EXV_HAVE_XMP_TOOLKIT undefined.
  Regression: Panasonic RW2 files are missing information.
  - Updated configuration files (config.guess, config.sub).
  - Added new Color Label value to digiKam 2.0.0 XMP namespace.
* Tue Jan 25 2011 wstephenson@novell.com
- Update to version 0.21
  + Exiv2 utility
  - grep should find all occurrences of a tag, not only one.
  - Added option -q (quiet) to silence warnings and error messages
    from the Exiv2 library to the exiv2 command line tool.
  - Allow "migration" of XMP namespaces.
  + Exiv2 library
  - Error handler: Applications should be able to register an error
    handler.
  - Silence warnings from code.
  - Support of Sigma 17-50 2.8 OS HSM.
  - Tag 0x0203 in Olympus makernotes should be "Lens ID".
  - Remove makernote classes and pretty-print functions from the
    published interface.
  - Remove IfdId from the published interface.
  - Add support for Samsung's .SRW raw format.
  - Need a way to get a list of all supported tags.
  - The default type of Array element tags is incorrect.
  - New image formats and improved makernote support should not
    break ABI.
  - Lensname missing with EF100mm f/2.8L Macro IS USM.
  - exiv2 0.20 is corrupting ORF files from E-PL1.
  - Problem compiling with Sun Studio - visibility.
  - Writing Exif.Image.ImageDescription in ORF file corrupts file.
  - Support for Tamron 17-50mm f/2.8 SP XR LD II Di VC.
  - Support for Sigma AF 50mm f/1.4 EX DG HSM.
  - Exiv2 crash on "print".
  - Metadata of Canon EF-S 18-55mm are not read correctly.
  - exiv2 crashes when examining previews.
  - Typo in XMPCore_Impl.hpp.
  - Missing header in canonmp.cpp.
  - Fix pkg-config file.
  - PSD resource block handling patch.
  - Updated Nikon Lens lookup table to v4.3.410.01 of
    Robert Rottmerhusen's fmountlens list.
  - Introduced exiv2.hpp as a wrapper to include all Exiv2 objects.
  - Added a count field to the Exif tag reference data.
  - Added ExifKey::defaultCount() to access the new count reference
    information.
  - Fixed zlib uncompression of large PNG metadata buffers.
  - Improved determination of MIME type.
  - Updated Canon makernote.
  - Updated Olympus makernote.
  - Updated Sony and Minolta makernote tags.
  - Fixed writing to pseudo memory mapped areas on Linux.
  - Modified test for XMP files to not recognize any XML file with
    a regular header as XMP.
  - Added afPoint() easy-access function.
  - Updated Spanish translations.
* Mon Aug  9 2010 vuntz@opensuse.org
- Update to version 0.20:
  + Exiv2 utility
  - %%a broken in rename
  - It should be possible to insert newlines in text strings.
  - Exif.Photo.UserComment unicode comment doesn't work
    (deb#486884)
  - Added -g option to 'grep' info for individual tags.
  + Exiv2 library
  - Pentax 645D makernote update
  - Update of Pentax makernote
  - Nikon Capture NX won't save a NEF file manipulated with exiv2
    from SVN
  - Padding of XMP data results in invalid XMP JPEG segment
    larger than 65535 bytes
  - Add XMP support for src/metacopy
  - src/psdimage.cpp: operands of ? are integers of different
    signs: 'unsigned int' and 'long'
  - Wrong conversion of IPTC SpecialInstructions in copyIptcToXmp()
  - LLVM clang: error: default initialization of an object of
    const type 'class Exiv2::IptcData const' requires a
    user-provided default constructor.
  - Exif.Image.SubIFDs should support more than 4 sub-IFDs
  - Nikon Makernote tags regression in exiv 0.19 (deb#579835)
  - ShutterSpeedValue should be a signed rational
  - Allow XMP sidecar files which start with a UTF-8 BOM
  - Image file gets deleted when writing to it
  - Writing to read-only TIFF-like file fails
  - "TIFF-safe" setExifData variant
  - Optimize binary array elements
  - Write support for Olympus RAW ORF files
  - Incorrect Unicode encoding of Exif UserComment tag
  - LensType not reported for Pentax K-x
  - Add support for makernote of Sony ARW files
  - Unable to write GPS data in ORF files with digikam
  - Added Kipi XMP namespace used by digiKam kipi-plugins
  - Added iView Media Pro and MS Expression Media XMP schemas.
  - Generalized class Error, added class WError for use with
    Unicode-Paths.
  - Updated Nikon Lens lookup table to v4.3.401.01 of Robert
    Rottmerhusen's fmountlens list.
  - Various fixes and enhancements when building with MSVC.
  - Added several missing TIFF tags (from PageMaker 6.0, Adobe
    OPI TIFF, Adobe TIFF&PM6 and TIFF/EP specs).
  - Completed support for Nikon makernote
- Rename libexiv2-6 to libexiv2-9 following library version bump.
- Add pkg-config BuildRequires to have pkgconfig() Provides.
* Sun Jan 31 2010 jengelh@medozas.de
- Package baselibs.conf
* Wed Jan  6 2010 vuntz@opensuse.org
- Update to version 0.19:
  + See complete changes at http://www.exiv2.org/changelog.html
  + Exiv2 utility
  - Inverted the meaning of -u to deal with large numbers of
    unknown Nikon Makernote tags.
  - -b option now also suppresses Byte and SByte values.
  + Exiv2 library
  - Fix various bugs, crashes and exceptions.
  - Add exif tag: TimeZoneOffset (0x882a) and other TIFF/EP tags.
  - Additional lens data.
  - Update Nikon makernotes.
  - Optimize TIFF writing.
  - Upgrade XMP Toolkit to version 4.4.2.
  - Remove FindMetadatum* from API.
  - Convert character set when writing XMP sidecar.
  - Support multiple APP13 Photoshop 3.0 segments in a JPEG.
  - Changed FileIo and MemIo classes to use a Pimpl structure.
  - Removed --disable-printucs2 configure option.
  - Updated config files
  - Added support for Canon FileInfo tags.
  - Updated Nikon Lens lookup table to v4.1.361.01 of
    Robert Rottmerhusen's fmountlens list.
  - Added Sigma 28-80mm f/3.5-5.6 lens.
  - Added easy-access functions saturation, sharpness, contrast and
    sceneCaptureType.
  - Support for PGF files added.
  - Updated digiKam XMP properties.
  - Added iptc4xmpExt and plus XMP schemas.
  - Some windows-specific change.
  - Updated translations.
- Drop gcc43.diff: it's not needed anymore.
- Change libexiv2-5 to libexiv2-6, following soname change.
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Fri Jul 24 2009 beineri@opensuse.org
- update to 0.18.2, fixed issues:
  * Exiv2 corrupts certain NEF images when writing to them.
  * Editing via symlink does not work as expected.
  * PNG images: CRC error in chunk zTXt.
  * JPG images: Exiv2 puts comments directly after SOI.
  * PNG images: Setting IPTC preview corrupts PNG image.
* Tue May  5 2009 wstephenson@novell.com
- update to 0.18.1:
  * added new 'organize' tool
  * bug fixes
  * for changelog see http://www.exiv2.org/changelog.html
* Mon Feb 16 2009 coolo@suse.de
- forgot one package rename
* Sun Feb 15 2009 coolo@suse.de
- update to 0.18:
  * mostly bug fixes
  * for changelog see http://www.exiv2.org/changelog.html
* Sun Feb 15 2009 coolo@suse.de
- more includes for gcc 4.4
* Thu Nov 27 2008 ro@suse.de
- update baselibs.conf
* Sun Aug 31 2008 crrodriguez@suse.de
- kill libexiv2.la, aka. the real fix for gwenview build failure.
- correct requires of -devel packages
* Mon Jun 30 2008 dmueller@suse.de
- update to 0.17.1:
  * for changelog see http://www.exiv2.org/changelog.html
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Feb 27 2008 dmueller@suse.de
- fix build for older distributions
* Tue Feb 26 2008 dmueller@suse.de
- fix obsoletes/requires/provides
* Mon Feb 18 2008 adrian@suse.de
- split and rename package to exiv2/libexiv2-2 to follow library policy
- reduce package size with fdupes
- drop SL 9.3 specific patch
* Sun Feb 10 2008 adrian@suse.de
- update to version 0.16:
  * adds XMP support
  * Broken PNG image causes exiv2 to crash
  * Read IPTC data from multiple APP13 Photoshop 3.0 segments
  * Pentax lens info decoding.
  * Updated Nikon lens info to v2.99
  * Added reference tables for XMP properties to documentation.
  * Updated translations
  * Add support for Pentax maker note
  * Lightzone-created JPEG causes exiv2 to segfault
  * Support for Olympus ORF format
  * Added Minolta lenses
  * Ported various Exif tags from Exiftool
  * Added i18n for XMP properties, XMP support in PNG images
- drop obsolete patches and redo gcc43.diff
* Sat Dec 15 2007 dmueller@suse.de
- fix integer overflows (CVE-2007-6353, #348748)
* Thu Oct  4 2007 dmueller@suse.de
- fix build with gcc 4.3 (upstream backport)
* Fri Aug 31 2007 dmueller@suse.de
- update to 0.15:
  * Image with large invalid Exif tag crashes exiv2.
    (Reported by Marco Piovanelli)
  * crash when loading certain image.
  * Another Minolta G500 file impossible to read after fix.
  * Sony Makernote crashes exiv2.
  * Wrong AFPoints mapping for Canon cameras.
  * Minolta G500 RAW format support.
  * Fix "Since v0.14 the version check macro doesn't work in a precompiler
    [#]if test anymore".
  * [jpeg i/o] Uncouple IPTC and Exif reading.
  * Updated Nikon lens info to v2.30 of Robert Rottmerhusen's lens database.
  * Added additional values to the Exif.CanonCs.ISOSpeed. lookup table.
  * Canon ModelId patch. (Gerry Patterson)
  * Updated German translation.
  * Updated Russian translation.
  * Updated French translation.
* Thu Apr 12 2007 dmueller@suse.de
- update to version 0.14:
  * Fixed mapping of CRW rotation info to Exif orientation.
  (Reported and analysed by Marco Piovanelli)
  * Fixed RAF read-support for systems without mmap. (Reported
    by Udi Fuchs)
  * [exif] Added tag names for a few tags used by Windows Vista and
    ACDSee. (Gilles Caulier)
  * [exif] Updated Nikon lens info to v2.20 of Robert Rottmerhusen's
    lens database.
  * [miscellaneous] Changed AnyError to inherit from std::exception;
    changed the signature of AnyError::what(). (Suggested by Marco
    Piovanelli)
  * [miscellaneous] Fixed version check macro to actually check the
    runtime version and not the compile-time version. Added version()
    and versionNumber() functions.
  * [miscellaneous] Updated German translation. (Oliver Dörr)
  * [miscellaneous] Changed name of installed translation files to
    lower case exiv2.mo. (Highlighted by Angelo Naselli)
    Tiff generated by photoshop crashes exiv2
    (digikam bug 139658).
  * New TIFF parser: Decode IPTC from Exif.Image.IPTCNAA.
    (Reported by Walter Hangartner)
  * IPTC field parsing is still too strict: shouldn't fail if
    the type is not as expected. (Reported by Elsa Nordh)
  * exiv2 tool doesn't respect unix file rights. (Reported and
    analysed by fabien)
  * Probe exiv2 for the extensions it supports.
    (Suggested by Will Stokes)
  * Add i18n support. Requires gettext.
* Thu Mar 29 2007 rguenther@suse.de
- add zlib-devel BuildRequires
* Tue Nov 28 2006 adrian@suse.de
- update to version 0.12
  * Exiv2 utility
  - 0000493: [tools] exiv2 -T DST problem.
  - 0000459: [exif] Exiv2 tool: Added a variable for the original filename to
    the rename option. (Patch by Tobias Jahn)
  * Exiv2 library
  - 0000498: [exif] Exiv2 cannot read the Exif data written after deleting all
    tags.
  - 0000496: [metadata] Digikam bug 136855: Editing metadata on a few selected
    imagefiles and clicking forward or apply crashes digikam.
    (Reported by several digikam users)
  - 0000495: [exif] Image with corrupted metadata crashes Exiv2. (Reported as
    digikam bug 136932 by Rainer Krienke)
  - 0000489: [build environment] exiv2.pc.in includes private/static libs by
    default. (Reported with patch by Rex Dieter)
  - 0000488: [metadata] GPSInfo Metadata should return decimal numbers.
    (Feature requested by Fabien)
  - 0000486: [build environment] Test bugfixes-test.sh error under Mac OS X x86.
    (Reported with fix by Max Lapshin)
  - [exif] Updated Nikon lens info to v2.07 of Robert Rottmerhusen's
    lens database.
  - [metadata] Added methods to access built-in read-only Exif taglists
    and IPTC record lists. (Initiated by Max Lapshin)
  - [iptc] Improved IPTC record descriptions using IIM4 specification
    version 4.1. (Gilles Caulier)
  - [exif] Improved Exif tag descriptions using Exif specification 2.2
    and libexif. (Gilles Caulier)
  - [exif] Added and improved pretty print functions for some Exif
    tags. (Gilles Caulier)
  - [exif] Updated Minolta makernote. (Gilles Caulier, Paul Tribick)
* Tue Nov  7 2006 dmueller@suse.de
- don't build as root
* Tue Nov  7 2006 dmueller@suse.de
- Initial package (0.11), adopted from openSUSE buildservice
